package com.cpp.web.domain.station;

import com.baomidou.mybatisplus.annotation.TableName;

import com.cpp.web.domain.BaseCppEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.Digits;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * cpp_inverter_status_data
 *
 * @author tl
 * @date 2024-09-23 15:28:33
 */
@Data
@TableName("cpp_inverter_status_data")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "cpp_inverter_status_data")
public class InverterStatusData extends BaseCppEntity {


    /**
     * 设备主键ID
     */
    @ApiModelProperty(value = "设备主键ID")
    private Long equipmentId;


    /**
     * 状态值为1代表运行，2代表待机，3代表停用，4代表故障
     */
    @ApiModelProperty(value = "状态值为1代表运行，2代表待机，3代表停用，4代表故障")
    private String status;


    /**
     * 时间
     */
    @ApiModelProperty(value = "时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date time;



    /**
     * 有功（KW）
     */
    @ApiModelProperty(value = "有功（KW）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal activePower = new BigDecimal(-99);


    /**
     * 无功（KVar）
     */
    @ApiModelProperty(value = "无功（KVar）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal reactivePower = new BigDecimal(-99);


    /**
     * 功率因数
     */
    @ApiModelProperty(value = "功率因数")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal powerFactor = new BigDecimal(-99);


    /**
     * 电压
     */
    @ApiModelProperty(value = "电压")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal voltage = new BigDecimal(-99);


    /**
     * 电流
     */
    @ApiModelProperty(value = "电流")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal electricalCurrent = new BigDecimal(-99);


    /**
     * 当日发电量
     */
    @ApiModelProperty(value = "当日发电量")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal dayElectricQuantity = new BigDecimal(-99);


    /**
     * 累积发电量
     */
    @ApiModelProperty(value = "累积发电量")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal cumulativeGeneratedEnergy = new BigDecimal(-99);


    /**
     * 当日并网小时数
     */
    @ApiModelProperty(value = "当日并网小时数")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal dayGridConnectedHours = new BigDecimal(-99);


}
