package com.cpp.web.domain.station;

import com.baomidou.mybatisplus.annotation.TableName;

import com.cpp.web.domain.BaseCppEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.Digits;
import java.math.BigDecimal;
import java.util.Date;

/**
 * cpp_weather_station_status_data
 *
 * @author tl
 * @date 2024-09-23 15:28:33
 */
@Data
@TableName("cpp_weather_station_status_data")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "cpp_weather_station_status_data")
public class WeatherStationStatusData extends BaseCppEntity {


    /**
     * 设备主键ID
     */
    @ApiModelProperty(value = "设备主键ID")
    private Long equipmentId;


    /**
     * 状态值为1代表运行，2代表待机，3代表停用，4代表故障
     */
    @ApiModelProperty(value = "状态值为1代表运行，2代表待机，3代表停用，4代表故障")
    private String status;


    /**
     * 时间
     */
    @ApiModelProperty(value = "时间")
    private Date time;

    /**
     * 总辐射（W/㎡）
     */
    @ApiModelProperty(value = "总辐射（W/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal globalR = new BigDecimal(-99);


    /**
     * 直接辐射（W/㎡）
     */
    @ApiModelProperty(value = "直接辐射（W/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal directR = new BigDecimal(-99);


    /**
     * 散射辐射（W/㎡）
     */
    @ApiModelProperty(value = "散射辐射（W/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal diffuseR = new BigDecimal(-99);


    /**
     * 斜面辐射（W/㎡）
     */
    @ApiModelProperty(value = "斜面辐射（W/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal obliqueR = new BigDecimal(-99);


    /**
     * 环境温度（℃）
     */
    @ApiModelProperty(value = "环境温度（℃）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal airT = new BigDecimal(-99);


    /**
     * 气压（KPa）
     */
    @ApiModelProperty(value = "气压（KPa）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal p = new BigDecimal(-99);


    /**
     * 湿度（%）
     */
    @ApiModelProperty(value = "湿度（%）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal rh = new BigDecimal(-99);


    /**
     * 光伏电池板温度（℃）
     */
    @ApiModelProperty(value = "光伏电池板温度（℃）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal cellT = new BigDecimal(-99);


    /**
     * 风速（m/s）
     */
    @ApiModelProperty(value = "风速（m/s）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal ws = new BigDecimal(-99);


    /**
     * 风向（°）
     */
    @ApiModelProperty(value = "风向（°）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal wd = new BigDecimal(-99);


    /**
     * 日照小时数
     */
    @ApiModelProperty(value = "日照小时数")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal hourDA = new BigDecimal(-99);


    /**
     * 总辐射日累计（MJ/㎡）
     */
    @ApiModelProperty(value = "总辐射日累计（MJ/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal globalRDA = new BigDecimal(-99);


    /**
     * 直接辐射日累计（MJ/㎡）
     */
    @ApiModelProperty(value = "直接辐射日累计（MJ/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal directRDA = new BigDecimal(-99);


    /**
     * 散射辐射日累计（MJ/㎡）
     */
    @ApiModelProperty(value = "散射辐射日累计（MJ/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal diffuseRDA = new BigDecimal(-99);


    /**
     * 斜面辐射日累计（MJ/㎡）
     */
    @ApiModelProperty(value = "斜面辐射日累计（MJ/㎡）")
    @Digits(integer = 10, fraction = 2)
    private BigDecimal obliqueRDA = new BigDecimal(-99);


    /**
     * 数据是否是通过预测数据生成的
     */
    @ApiModelProperty(value = "数据是否是通过预测数据生成的")
    private String isGenerated;


}
