package com.cpp.web.domain.station;

import com.baomidou.mybatisplus.annotation.TableName;

import com.cpp.web.domain.BaseCppEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.Digits;
import java.math.BigDecimal;
import java.util.Date;

/**
 * cpp_wind_tower_status_data
 *
 * @author tl
 * @date 2024-09-23 15:28:33
 */
@Data
@TableName("cpp_wind_tower_status_data")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "cpp_wind_tower_status_data")
public class WindTowerStatusData extends BaseCppEntity {


    /**
     * 设备主键ID
     */
    @ApiModelProperty(value = "设备主键ID")
    private Long equipmentId;


    /**
     * 状态值为1代表运行，2代表待机，3代表停用，4代表故障
     */
    @ApiModelProperty(value = "状态值为1代表运行，2代表待机，3代表停用，4代表故障")
    private String status;


    /**
     * 时间
     */
    @ApiModelProperty(value = "时间")
    private Date time;


    /**
     * 温度瞬时值
     */
    @ApiModelProperty(value = "温度瞬时值（℃）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal tInst = new BigDecimal(-99);


    /**
     * 温度最大值（℃）
     */
    @ApiModelProperty(value = "温度最大值（℃）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal tMax = new BigDecimal(-99);


    /**
     * 温度最小值（℃）
     */
    @ApiModelProperty(value = "温度最小值（℃）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal tMin = new BigDecimal(-99);


    /**
     * 温度平均值（℃）
     */
    @ApiModelProperty(value = "温度平均值（℃）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal tAve = new BigDecimal(-99);


    /**
     * 温度标准差（℃）
     */
    @ApiModelProperty(value = "温度标准差（℃）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal tSta = new BigDecimal(-99);


    /**
     * 湿度瞬时值（%）
     */
    @ApiModelProperty(value = "湿度瞬时值（%）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal rhInst = new BigDecimal(-99);


    /**
     * 湿度最大值（%）
     */
    @ApiModelProperty(value = "湿度最大值（%）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal rhMax = new BigDecimal(-99);


    /**
     * 湿度最小值（%）
     */
    @ApiModelProperty(value = "湿度最小值（%）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal rhMin = new BigDecimal(-99);


    /**
     * 湿度平均值（%）
     */
    @ApiModelProperty(value = "湿度平均值（%）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal rhAve = new BigDecimal(-99);


    /**
     * 湿度标准差（%）
     */
    @ApiModelProperty(value = "湿度标准差（%）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal rhSta = new BigDecimal(-99);


    /**
     * 气压瞬时值（KPa）
     */
    @ApiModelProperty(value = "气压瞬时值（KPa）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal paInst = new BigDecimal(-99);


    /**
     * 气压最大值（KPa）
     */
    @ApiModelProperty(value = "气压最大值（KPa）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal paMax = new BigDecimal(-99);


    /**
     * 气压最小值（KPa）
     */
    @ApiModelProperty(value = "气压最小值（KPa）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal paMin = new BigDecimal(-99);


    /**
     * 气压平均值（KPa）
     */
    @ApiModelProperty(value = "气压平均值（KPa）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal paAve = new BigDecimal(-99);


    /**
     * 气压标准差（KPa）
     */
    @ApiModelProperty(value = "气压标准差（KPa）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal paSta = new BigDecimal(-99);


    /**
     * 10米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "10米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst10 = new BigDecimal(-99);


    /**
     * 10米风速最大值（m/s）
     */
    @ApiModelProperty(value = "10米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax10 = new BigDecimal(-99);


    /**
     * 10米风速最小值（m/s）
     */
    @ApiModelProperty(value = "10米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin10 = new BigDecimal(-99);


    /**
     * 10米风速平均值（m/s）
     */
    @ApiModelProperty(value = "10米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve10 = new BigDecimal(-99);


    /**
     * 10米风速标准差（m/s）
     */
    @ApiModelProperty(value = "10米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta10 = new BigDecimal(-99);


    /**
     * 10米风向瞬时值（°）
     */
    @ApiModelProperty(value = "10米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst10 = new BigDecimal(-99);


    /**
     * 10米风向最大值（°）
     */
    @ApiModelProperty(value = "10米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax10 = new BigDecimal(-99);


    /**
     * 10米风向最小值（°）
     */
    @ApiModelProperty(value = "10米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin10 = new BigDecimal(-99);


    /**
     * 10米风向平均值（°）
     */
    @ApiModelProperty(value = "10米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve10 = new BigDecimal(-99);


    /**
     * 10米风向标准差（°）
     */
    @ApiModelProperty(value = "10米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta10 = new BigDecimal(-99);


    /**
     * 30米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "30米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst30 = new BigDecimal(-99);


    /**
     * 30米风速最大值（m/s）
     */
    @ApiModelProperty(value = "30米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax30 = new BigDecimal(-99);


    /**
     * 30米风速最小值（m/s）
     */
    @ApiModelProperty(value = "30米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin30 = new BigDecimal(-99);


    /**
     * 30米风速平均值（m/s）
     */
    @ApiModelProperty(value = "30米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve30 = new BigDecimal(-99);


    /**
     * 30米风速标准差（m/s）
     */
    @ApiModelProperty(value = "30米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta30 = new BigDecimal(-99);


    /**
     * 30米风向瞬时值（°）
     */
    @ApiModelProperty(value = "30米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst30 = new BigDecimal(-99);


    /**
     * 30米风向最大值（°）
     */
    @ApiModelProperty(value = "30米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax30 = new BigDecimal(-99);


    /**
     * 30米风向最小值（°）
     */
    @ApiModelProperty(value = "30米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin30 = new BigDecimal(-99);


    /**
     * 30米风向平均值（°）
     */
    @ApiModelProperty(value = "30米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve30 = new BigDecimal(-99);


    /**
     * 30米风向标准差（°）
     */
    @ApiModelProperty(value = "30米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta30 = new BigDecimal(-99);


    /**
     * 50米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "50米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst50 = new BigDecimal(-99);


    /**
     * 50米风速最大值（m/s）
     */
    @ApiModelProperty(value = "50米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax50 = new BigDecimal(-99);


    /**
     * 50米风速最小值（m/s）
     */
    @ApiModelProperty(value = "50米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin50 = new BigDecimal(-99);


    /**
     * 50米风速平均值（m/s）
     */
    @ApiModelProperty(value = "50米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve50 = new BigDecimal(-99);


    /**
     * 50米风速标准差（m/s）
     */
    @ApiModelProperty(value = "50米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta50 = new BigDecimal(-99);


    /**
     * 50米风向瞬时值（°）
     */
    @ApiModelProperty(value = "50米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst50 = new BigDecimal(-99);


    /**
     * 50米风向最大值（°）
     */
    @ApiModelProperty(value = "50米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax50 = new BigDecimal(-99);


    /**
     * 50米风向最小值（°）
     */
    @ApiModelProperty(value = "50米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin50 = new BigDecimal(-99);


    /**
     * 50米风向平均值（°）
     */
    @ApiModelProperty(value = "50米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve50 = new BigDecimal(-99);


    /**
     * 50米风向标准差（°）
     */
    @ApiModelProperty(value = "50米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta50 = new BigDecimal(-99);


    /**
     * 60米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "60米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst60 = new BigDecimal(-99);


    /**
     * 60米风速最大值（m/s）
     */
    @ApiModelProperty(value = "60米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax60 = new BigDecimal(-99);


    /**
     * 60米风速最小值（m/s）
     */
    @ApiModelProperty(value = "60米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin60 = new BigDecimal(-99);


    /**
     * 60米风速平均值（m/s）
     */
    @ApiModelProperty(value = "60米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve60 = new BigDecimal(-99);


    /**
     * 60米风速标准差（m/s）
     */
    @ApiModelProperty(value = "60米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta60 = new BigDecimal(-99);


    /**
     * 60米风向瞬时值（°）
     */
    @ApiModelProperty(value = "60米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst60 = new BigDecimal(-99);


    /**
     * 60米风向最大值（°）
     */
    @ApiModelProperty(value = "60米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax60 = new BigDecimal(-99);


    /**
     * 60米风向最小值（°）
     */
    @ApiModelProperty(value = "60米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin60 = new BigDecimal(-99);


    /**
     * 60米风向平均值（°）
     */
    @ApiModelProperty(value = "60米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve60 = new BigDecimal(-99);


    /**
     * 60米风向标准差（°）
     */
    @ApiModelProperty(value = "60米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta60 = new BigDecimal(-99);


    /**
     * 70米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "70米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst70 = new BigDecimal(-99);


    /**
     * 70米风速最大值（m/s）
     */
    @ApiModelProperty(value = "70米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax70 = new BigDecimal(-99);


    /**
     * 70米风速最小值（m/s）
     */
    @ApiModelProperty(value = "70米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin70 = new BigDecimal(-99);


    /**
     * 70米风速平均值（m/s）
     */
    @ApiModelProperty(value = "70米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve70 = new BigDecimal(-99);


    /**
     * 70米风速标准差（m/s）
     */
    @ApiModelProperty(value = "70米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta70 = new BigDecimal(-99);


    /**
     * 70米风向瞬时值（°）
     */
    @ApiModelProperty(value = "70米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst70 = new BigDecimal(-99);


    /**
     * 70米风向最大值（°）
     */
    @ApiModelProperty(value = "70米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax70 = new BigDecimal(-99);


    /**
     * 70米风向最小值（°）
     */
    @ApiModelProperty(value = "70米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin70 = new BigDecimal(-99);


    /**
     * 70米风向平均值（°）
     */
    @ApiModelProperty(value = "70米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve70 = new BigDecimal(-99);


    /**
     * 70米风向标准差（°）
     */
    @ApiModelProperty(value = "70米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta70 = new BigDecimal(-99);


    /**
     * 80米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "80米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst80 = new BigDecimal(-99);


    /**
     * 80米风速最大值（m/s）
     */
    @ApiModelProperty(value = "80米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax80 = new BigDecimal(-99);


    /**
     * 80米风速最小值（m/s）
     */
    @ApiModelProperty(value = "80米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin80 = new BigDecimal(-99);


    /**
     * 80米风速平均值（m/s）
     */
    @ApiModelProperty(value = "80米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve80 = new BigDecimal(-99);


    /**
     * 80米风速标准差（m/s）
     */
    @ApiModelProperty(value = "80米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta80 = new BigDecimal(-99);


    /**
     * 80米风向瞬时值（°）
     */
    @ApiModelProperty(value = "80米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst80 = new BigDecimal(-99);


    /**
     * 80米风向最大值（°）
     */
    @ApiModelProperty(value = "80米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax80 = new BigDecimal(-99);


    /**
     * 80米风向最小值（°）
     */
    @ApiModelProperty(value = "80米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin80 = new BigDecimal(-99);


    /**
     * 80米风向平均值（°）
     */
    @ApiModelProperty(value = "80米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve80 = new BigDecimal(-99);


    /**
     * 80米风向标准差（°）
     */
    @ApiModelProperty(value = "80米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta80 = new BigDecimal(-99);


    /**
     * 90米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "90米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst90 = new BigDecimal(-99);


    /**
     * 90米风速最大值（m/s）
     */
    @ApiModelProperty(value = "90米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax90 = new BigDecimal(-99);


    /**
     * 90米风速最小值（m/s）
     */
    @ApiModelProperty(value = "90米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin90 = new BigDecimal(-99);


    /**
     * 90米风速平均值（m/s）
     */
    @ApiModelProperty(value = "90米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve90 = new BigDecimal(-99);


    /**
     * 90米风速标准差（m/s）
     */
    @ApiModelProperty(value = "90米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta90 = new BigDecimal(-99);


    /**
     * 90米风向瞬时值（°）
     */
    @ApiModelProperty(value = "90米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst90 = new BigDecimal(-99);


    /**
     * 90米风向最大值（°）
     */
    @ApiModelProperty(value = "90米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax90 = new BigDecimal(-99);


    /**
     * 90米风向最小值（°）
     */
    @ApiModelProperty(value = "90米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin90 = new BigDecimal(-99);


    /**
     * 90米风向平均值（°）
     */
    @ApiModelProperty(value = "90米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve90 = new BigDecimal(-99);


    /**
     * 90米风向标准差（°）
     */
    @ApiModelProperty(value = "90米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta90 = new BigDecimal(-99);


    /**
     * 100米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "100米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst100 = new BigDecimal(-99);


    /**
     * 100米风速最大值（m/s）
     */
    @ApiModelProperty(value = "100米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax100 = new BigDecimal(-99);


    /**
     * 100米风速最小值（m/s）
     */
    @ApiModelProperty(value = "100米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin100 = new BigDecimal(-99);


    /**
     * 100米风速平均值（m/s）
     */
    @ApiModelProperty(value = "100米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve100 = new BigDecimal(-99);


    /**
     * 100米风速标准差（m/s）
     */
    @ApiModelProperty(value = "100米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta100 = new BigDecimal(-99);


    /**
     * 100米风向瞬时值（°）
     */
    @ApiModelProperty(value = "100米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst100 = new BigDecimal(-99);


    /**
     * 100米风向最大值（°）
     */
    @ApiModelProperty(value = "100米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax100 = new BigDecimal(-99);


    /**
     * 100米风向最小值（°）
     */
    @ApiModelProperty(value = "100米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin100 = new BigDecimal(-99);


    /**
     * 100米风向平均值（°）
     */
    @ApiModelProperty(value = "100米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve100 = new BigDecimal(-99);


    /**
     * 100米风向标准差（°）
     */
    @ApiModelProperty(value = "100米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta100 = new BigDecimal(-99);


    /**
     * 110米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "110米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst110 = new BigDecimal(-99);


    /**
     * 110米风速最大值（m/s）
     */
    @ApiModelProperty(value = "110米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax110 = new BigDecimal(-99);


    /**
     * 110米风速最小值（m/s）
     */
    @ApiModelProperty(value = "110米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin110 = new BigDecimal(-99);


    /**
     * 110米风速平均值（m/s）
     */
    @ApiModelProperty(value = "110米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve110 = new BigDecimal(-99);


    /**
     * 110米风速标准差（m/s）
     */
    @ApiModelProperty(value = "110米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta110 = new BigDecimal(-99);


    /**
     * 110米风向瞬时值（°）
     */
    @ApiModelProperty(value = "110米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst110 = new BigDecimal(-99);


    /**
     * 110米风向最大值（°）
     */
    @ApiModelProperty(value = "110米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax110 = new BigDecimal(-99);


    /**
     * 110米风向最小值（°）
     */
    @ApiModelProperty(value = "110米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin110 = new BigDecimal(-99);


    /**
     * 110米风向平均值（°）
     */
    @ApiModelProperty(value = "110米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve110 = new BigDecimal(-99);


    /**
     * 110米风向标准差（°）
     */
    @ApiModelProperty(value = "110米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta110 = new BigDecimal(-99);


    /**
     * 120米风速瞬时值（m/s）
     */
    @ApiModelProperty(value = "120米风速瞬时值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInst120 = new BigDecimal(-99);


    /**
     * 120米风速最大值（m/s）
     */
    @ApiModelProperty(value = "120米风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMax120 = new BigDecimal(-99);


    /**
     * 120米风速最小值（m/s）
     */
    @ApiModelProperty(value = "120米风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMin120 = new BigDecimal(-99);


    /**
     * 120米风速平均值（m/s）
     */
    @ApiModelProperty(value = "120米风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAve120 = new BigDecimal(-99);


    /**
     * 120米风速标准差（m/s）
     */
    @ApiModelProperty(value = "120米风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsSta120 = new BigDecimal(-99);


    /**
     * 120米风向瞬时值（°）
     */
    @ApiModelProperty(value = "120米风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInst120 = new BigDecimal(-99);


    /**
     * 120米风向最大值（°）
     */
    @ApiModelProperty(value = "120米风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMax120 = new BigDecimal(-99);


    /**
     * 120米风向最小值（°）
     */
    @ApiModelProperty(value = "120米风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMin120 = new BigDecimal(-99);


    /**
     * 120米风向平均值（°）
     */
    @ApiModelProperty(value = "120米风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAve120 = new BigDecimal(-99);


    /**
     * 120米风向标准差（°）
     */
    @ApiModelProperty(value = "120米风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdSta120 = new BigDecimal(-99);


    /**
     * 风机轮毂高度风速瞬时值
     */
    @ApiModelProperty(value = "风机轮毂高度风速瞬时值")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsInstHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风速最大值（m/s）
     */
    @ApiModelProperty(value = "风机轮毂高度风速最大值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMaxHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风速最小值（m/s）
     */
    @ApiModelProperty(value = "风机轮毂高度风速最小值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsMinHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风速平均值（m/s）
     */
    @ApiModelProperty(value = "风机轮毂高度风速平均值（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsAveHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风速标准差（m/s）
     */
    @ApiModelProperty(value = "风机轮毂高度风速标准差（m/s）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wsStaHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风向瞬时值（°）
     */
    @ApiModelProperty(value = "风机轮毂高度风向瞬时值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdInstHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风向最大值（°）
     */
    @ApiModelProperty(value = "风机轮毂高度风向最大值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMaxHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风向最小值（°）
     */
    @ApiModelProperty(value = "风机轮毂高度风向最小值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdMinHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风向平均值（°）
     */
    @ApiModelProperty(value = "风机轮毂高度风向平均值（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdAveHubHeight = new BigDecimal(-99);


    /**
     * 风机轮毂高度风向标准差（°）
     */
    @ApiModelProperty(value = "风机轮毂高度风向标准差（°）")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal wdStaHubHeight = new BigDecimal(-99);


    /**
     * 空气密度  Kg/m³
     */
    @ApiModelProperty(value = "空气密度  Kg/m³")
    @Digits(integer = 10, fraction = 4)
    private BigDecimal airDensity = new BigDecimal(-99);


    /**
     * 数据是否是通过预测数据生成的 1:是 0:否
     */
    @ApiModelProperty(value = "数据是否是通过预测数据生成的 1:是 0:否")
    private String isGenerated;


}
